@@ -1,9 +1,9 @@
 # find an available dir
 available_dir = function(dirs) {
   for (i in dirs) {
-    if (file_test('-d', i)) return(i)
+    if (utils::file_test('-d', i)) return(i)
   }
-  stop('none of the directories exists:\n', paste(formatUL(dirs), collapse = '\n'))
+  stop('none of the directories exists:\n', paste(utils::formatUL(dirs), collapse = '\n'))
 }
 
 # tailored for assert(): extract the expression that is likely to be useful for
@@ -19,3 +19,7 @@ deparse_key = function(expr) {
 all_true = function(x) {
   is.logical(x) && length(x) && !any(is.na(x)) && all(x)
 }
+
+insert_identical = function() {
+  rstudioapi::insertText(text = ' %==% ')
+}
